@@ -1,5 +1,5 @@
 /* snac - A simple, minimalistic ActivityPub instance */
-/* copyright (c) 2022 - 2025 grunfink et al. / MIT license */
+/* copyright (c) 2022 - 2026 grunfink et al. / MIT license */
 
 #include "xs.h"
 #include "xs_regex.h"
@@ -459,6 +459,9 @@ xs_str *sanitize(const char *content)
     char *p;
     const char *v;
 
+    if (!content)
+        return NULL;
+
     sl = xs_regex_split(content, "</?[^>]+>");
 
     p = sl;
